"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const busboy_1 = __importDefault(require("busboy"));
const os_1 = __importDefault(require("os"));
const fs_1 = __importDefault(require("fs"));
const path_1 = __importDefault(require("path"));
exports.parseFiles = (req) => {
    if (req.method !== 'POST' || !req.headers['content-type']) {
        return new Promise((resolve) => resolve({ files: {}, fields: {} }));
    }
    return new Promise((masterResolve) => {
        const busboy = new busboy_1.default({ headers: req.headers });
        const tmpdir = os_1.default.tmpdir();
        const fields = {};
        const files = {};
        busboy.on('field', (fieldName, val) => {
            fields[fieldName] = val;
        });
        const fileWrites = [];
        busboy.on('file', (fieldName, file, filename, encoding, mime) => {
            const filePath = path_1.default.join(tmpdir, filename);
            files[fieldName] = {
                path: filePath,
                type: mime,
                encoding,
                name: filename,
                file,
            };
            const writeStream = fs_1.default.createWriteStream(filePath);
            file.pipe(writeStream);
            const promise = new Promise((resolve, reject) => {
                file.on('end', () => {
                    writeStream.end();
                });
                writeStream.on('finish', resolve);
                writeStream.on('error', reject);
            });
            fileWrites.push(promise);
        });
        busboy.on('finish', async () => {
            if (fileWrites && Object.keys(files).length) {
                await Promise.all(fileWrites);
            }
            masterResolve({ files, fields });
        });
        busboy.end(req.rawBody);
    });
};
exports.cleanFiles = (files) => {
    Object.values(files).forEach((file) => {
        try {
            fs_1.default.unlinkSync(file.path);
        }
        catch (error) {
            if (error.code !== 'ENOENT') {
                throw error;
            }
        }
    });
};
