"use strict";
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (Object.hasOwnProperty.call(mod, k)) result[k] = mod[k];
    result["default"] = mod;
    return result;
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const chai_1 = __importStar(require("chai"));
const sinon_1 = __importDefault(require("sinon"));
const sinon_chai_1 = __importDefault(require("sinon-chai"));
const fs_1 = __importDefault(require("fs"));
const parse_files_1 = require("./parse-files");
chai_1.default.use(sinon_chai_1.default);
describe('parseFiles', function () {
    const files = {
        fileParam: {
            path: '/some/file.path.png',
            name: 'file.path.png',
            type: 'image/png',
            encoding: 'utf',
        },
    };
    afterEach(function () {
        sinon_1.default.restore();
    });
    context('one existing uploaded file', function () {
        let unlinkSyncStub;
        beforeEach(function () {
            unlinkSyncStub = sinon_1.default.stub(fs_1.default, 'unlinkSync').returns();
        });
        describe('.cleanFiles', function () {
            it('removes all stored files', function () {
                parse_files_1.cleanFiles(files);
                chai_1.expect(unlinkSyncStub).to.has.been.calledOnce;
            });
        });
    });
    context('one file doesn\'t exist', function () {
        beforeEach(function () {
            sinon_1.default.stub(fs_1.default, 'unlinkSync').throws({ code: 'ENOENT' });
        });
        describe('.cleanFiles', function () {
            it('omits non existing files', function () {
                chai_1.expect(() => parse_files_1.cleanFiles(files)).not.to.throw();
            });
        });
    });
});
